Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(227)

Unified Diff: base/task_scheduler/task_scheduler_impl.h

Issue 2068853002: Rename SchedulerThreadPool* to SchedulerWorkerPool* (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@rename1
Patch Set: CR Feedback fdoray@ Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/task_scheduler/sequence.h ('k') | base/task_scheduler/task_scheduler_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/task_scheduler/task_scheduler_impl.h
diff --git a/base/task_scheduler/task_scheduler_impl.h b/base/task_scheduler/task_scheduler_impl.h
index f9d789ea4c550daec7c001f591ce2068f672e936..eb568c8cd4d4bc7964b726f878f342498ef40e74 100644
--- a/base/task_scheduler/task_scheduler_impl.h
+++ b/base/task_scheduler/task_scheduler_impl.h
@@ -23,7 +23,7 @@ namespace base {
namespace internal {
class SchedulerServiceThread;
-class SchedulerThreadPoolImpl;
+class SchedulerWorkerPoolImpl;
// Default TaskScheduler implementation. This class is thread-safe.
class BASE_EXPORT TaskSchedulerImpl : public TaskScheduler {
@@ -55,8 +55,8 @@ class BASE_EXPORT TaskSchedulerImpl : public TaskScheduler {
void Initialize();
- // Returns the thread pool that runs Tasks with |traits|.
- SchedulerThreadPool* GetThreadPoolForTraits(const TaskTraits& traits);
+ // Returns the worker pool that runs Tasks with |traits|.
+ SchedulerWorkerPool* GetWorkerPoolForTraits(const TaskTraits& traits);
// Callback invoked when a non-single-thread |sequence| isn't empty after a
// worker thread pops a Task from it.
@@ -69,17 +69,17 @@ class BASE_EXPORT TaskSchedulerImpl : public TaskScheduler {
TaskTracker task_tracker_;
DelayedTaskManager delayed_task_manager_;
- // Thread pool for BACKGROUND Tasks without file I/O.
- std::unique_ptr<SchedulerThreadPoolImpl> background_thread_pool_;
+ // Worker pool for BACKGROUND Tasks without file I/O.
+ std::unique_ptr<SchedulerWorkerPoolImpl> background_worker_pool_;
- // Thread pool for BACKGROUND Tasks with file I/O.
- std::unique_ptr<SchedulerThreadPoolImpl> background_file_io_thread_pool_;
+ // Worker pool for BACKGROUND Tasks with file I/O.
+ std::unique_ptr<SchedulerWorkerPoolImpl> background_file_io_worker_pool_;
- // Thread pool for USER_VISIBLE and USER_BLOCKING Tasks without file I/O.
- std::unique_ptr<SchedulerThreadPoolImpl> normal_thread_pool_;
+ // Worker pool for USER_VISIBLE and USER_BLOCKING Tasks without file I/O.
+ std::unique_ptr<SchedulerWorkerPoolImpl> normal_worker_pool_;
- // Thread pool for USER_VISIBLE and USER_BLOCKING Tasks with file I/O.
- std::unique_ptr<SchedulerThreadPoolImpl> normal_file_io_thread_pool_;
+ // Worker pool for USER_VISIBLE and USER_BLOCKING Tasks with file I/O.
+ std::unique_ptr<SchedulerWorkerPoolImpl> normal_file_io_worker_pool_;
std::unique_ptr<SchedulerServiceThread> service_thread_;
« no previous file with comments | « base/task_scheduler/sequence.h ('k') | base/task_scheduler/task_scheduler_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698